async function dibujarMapa() {
    const json = colombia;
    const jsonDatos = datosMapa;
    var baseDatos = jslinq(jsonDatos);
    var consulta = baseDatos.distinct();
    var departamento = '', resultadosTmp = [], paginaActual = 1;

    var hexColor = '';
    const colores = { codigo: [] };

    json.features.forEach(depto => {
        switch (depto.properties.region) {
            case 'Amazonía':
                hexColor = '#3ccfc0';
                break;
            case 'Andina':
                hexColor = '#b082ce';
                break;
            case 'Caribe':
                hexColor = '#f59d39';
                break;
            case 'Orinoquía':
                hexColor = '#f8448c';
                break;
            case 'Pacífico':
                hexColor = '#3d817a';
                break;
            default:
                break;
        }
        colores.codigo.push(hexColor);
    });

    let w = 350;
    let h = 500;

    let projection = d3.geo.mercator()
        .center([-73, 4])
        .translate([w / 2, h / 2])
        .scale(1650);

    let path = d3.geo.path()
        .projection(projection);

    let svg = d3.select("#svganchor")
        .append("svg")
        .attr("width", w)
        .attr("height", h);

    svg.selectAll("path")
        .data(json.features)
        .enter()
        .append("path")
        .attr("d", path)
        .attr("stroke", "#fff")
        .attr("stroke-width", 1.125)
        .attr("fill", (d, i) => { return colores.codigo[i] })
        .on("mouseover", function (d, i) { d3.select(this).attr("opacity", 0.6) })
        .on("mouseout", function (d, i) { d3.select(this).attr("fill", colores.codigo[i]).attr("opacity", 1) })
        .on("click", function (d, i) {
            departamento = d.properties.nombre;
            consulta = baseDatos.where(function (el) { return el["Departamento"] == departamento });
            document.getElementById(d.properties.region).checked = true;
            document.querySelectorAll('input[name="organizacion"]').forEach(organizacion => organizacion.checked = false);
            reiniciarPagina();
            imprimirTarjetas(consulta.toList());
        });

    var filtroRegiones = document.querySelectorAll('input[name="region"]');
    filtroRegiones.forEach(region => region.addEventListener('change', () => {
        departamento = region.value;
        consulta = baseDatos.where(function (el) { return el["Región"] == region.value });
        document.querySelectorAll('input[name="organizacion"]').forEach(organizacion => organizacion.checked = false);
        reiniciarPagina();
        imprimirTarjetas(consulta.toList());
    }));

    var filtroOrganizacion = document.querySelectorAll('input[name="organizacion"]');
    filtroOrganizacion.forEach(organizacion => organizacion.addEventListener('change', () => {
        consultaOrg = consulta.where(function (el) { return el["Forma de organización"] == organizacion.value });
        reiniciarPagina();
        imprimirTarjetas(consultaOrg.toList());
    }));

    var filtroPagina = document.querySelector('input[name="filtroPagina"]');
    filtroPagina.addEventListener('change', () => {
        paginaActual = filtroPagina.value;
        imprimirTarjetas(resultadosTmp);
    });

    var paginaAnterior = document.getElementById('paginaAnterior');
    paginaAnterior.addEventListener('click', () => {
        if (paginaActual > filtroPagina.min) {
            paginaActual = paginaActual - 1;
            filtroPagina.value = paginaActual;
            imprimirTarjetas(resultadosTmp);
        }
    });

    var paginaSiguiente = document.getElementById('paginaSiguiente');
    paginaSiguiente.addEventListener('click', () => {
        if (paginaActual < filtroPagina.max) {
            paginaActual = parseInt(paginaActual) + 1;
            filtroPagina.value = paginaActual;
            imprimirTarjetas(resultadosTmp);
        }
    });

    function imprimirTarjetas(resultados) {
        var tarjeta = '', detalle = '', totalPorPagina = 8;
        resultadosTmp = resultados;
        document.getElementById("departamento").innerText = departamento;
        document.getElementById("creadores").innerText = resultados.length + ' creadores';

        document.getElementById("filtroPagina").max = totalPaginas(resultados.length, totalPorPagina);
        document.getElementById("filtroPaginaTotal").innerHTML = "de " + totalPaginas(resultados.length, totalPorPagina);

        var resultadosPag = paginar(resultados, totalPorPagina, paginaActual);
        resultadosPag.forEach((registro, indice) => {
            tarjeta += `<a href="#" data-toggle="modal" data-target="#tarjeta${indice}" class="list-group-item list-group-item-action col-md-6">
                <div class="d-flex w-100 justify-content-between">
                    <h5 class="iconoTarjeta mb-1">${registro["Nombres"]} ${registro["Apellidos"]}</h5>
                </div>
                <p class="mb-1">Ubicado en ${registro["Departamento"]} (región ${registro["Región"]})</p>
                <small>${registro["Cargo"]}</small>
                <span>Ver más</span>
            </a>`;
            detalle += `<div class="modal fade" id="tarjeta${indice}" tabindex="-1" aria-labelledby="tarjeta${indice}Label" aria-hidden="true">
                <div class="modal-dialog modal-dialog-centered">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h4 class="iconoTarjeta modal-title" id="tarjeta${indice}Label">${registro["Nombres"]} ${registro["Apellidos"]}</h4>
                        </div>
                        <div class="modal-body">
                            <p>Reside en ${registro["Municipio"]}, ${registro["Departamento"]} (región ${registro["Región"]})<br>
                            E-mail: <a href="mailto:${registro["Correo electrónico"]}">${registro["Correo electrónico"]}</a></p>
                            <h5>${registro["Forma de organización"]}</h5>
                            <p>${registro["Organización\/Proyecto"]}</p>
                            <h5>Funciones o cargo</h5>
                            <p>${registro["Cargo"]}</p>
                            <h5>Grupo étnico</h5>
                            <p>${registro["Grupo étnico"]}</p>
                            <h5>Grupos Poblacionales</h5>
                            <p>${registro["Grupos Poblacionales"]}</p>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-dismiss="modal">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>`;
        });
        if (resultadosPag.length == 0) tarjeta += '<p>Sin resultados. Selecciona otra ubicación o usa otras opciones de filtrado.</p>';
        document.getElementById("creadoresDepartamento").classList.remove("objetoInvisible");
        document.getElementById("paginador").classList.remove("sr-only");
        document.getElementById("listaResultados").classList.remove("objetoInvisible");
        document.getElementById("listaTarjetas").innerHTML = tarjeta;
        document.getElementById("detalleTarjetas").innerHTML = detalle;
    }

    function totalPaginas(total, totalPorPagina) {
        nPaginas = Math.floor(total / totalPorPagina) + 1;
        if (total % totalPorPagina == 0) nPaginas--;
        return nPaginas;
    }

    function paginar(arreglo, totalPorPagina, numeroPagina) {
        return arreglo.slice((numeroPagina - 1) * totalPorPagina, numeroPagina * totalPorPagina);
    }

    function reiniciarPagina() {
        paginaActual = 1;
        filtroPagina.value = paginaActual;
    }
}

dibujarMapa();